# (C) Copyright 2003 Nuxeo SARL <http://nuxeo.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# $Id: install.py,v 1.2 2004/02/17 14:58:12 dwyart Exp $

def install(self):
    """ Compatibility installer for CPS 3. Only required when you use products
    still requiring NuxMetaDirectories.

    Do not use or install NuxMetaDirectories if not required by any product.
    """
    _log = []
    def pr(bla, zlog=1, _log=_log):
        if bla == 'flush':
            return '<html><head><title>NuxMetaDirectories Installer</title></head><body><pre>'+ \
                   '\n'.join(_log) + \
                   '</pre></body></html>'

        _log.append(bla)
        if (bla and zlog):
            LOG('NuxMetaDirectories install:', INFO, bla)

    def prok(pr=pr):
        pr(" Already correctly installed")

    pr("Starting NuxMetaDirectories install")

    portal = self.portal_url.getPortalObject()

    def portalhas(id, portal=portal):
        return id in portal.objectIds()

    #
    # let's begin
    #
    if not portalhas('portal_metadirectories'):
        pr(" Creating CMF MetaDirectories Tool")
        portal.manage_addProduct["NuxMetaDirectories"].manage_addTool('CMF MetaDirectories Tool')

    mtool = portal.portal_metadirectories
    if "members" not in mtool.objectIds():
        pr("  Adding Member Areas : member")
        mtool.manage_addProduct['NuxMetaDirectories'].manage_addMembersDirectory(id='members',title='Members')
    if "groups" not in mtool.objectIds():
        pr("  Adding Group Directory : group")
        mtool.manage_addProduct['NuxMetaDirectories'].manage_addGroupsDirectory(id='groups', title='Groups')

    # Synchronization with MemberData
    mtool = portal.portal_metadirectories
    mtool.members.syncSchemaAndMemberData()

    # Verification of the action and addinf if neccesarly
    action_found = 0
    for action in portal['portal_actions'].listActions():
        if action.id == 'directories':
            action_found = 1

    if not action_found:
        portal['portal_actions'].addAction(
            id='directories',
            name='Directories',
            action='string: ${portal_url}/directories',
            condition='member',
            permission=('View',),
            category='global',
            visible=1)
        pr(" Added Action Directories")

    if 'cps_nuxmetadirectories' in portal.portal_skins.objectIds():
        pr(" Deleted obsolete skin")
        portal.portal_skins._delObject('cps_nuxmetadirectories')
        pr(" Resetting skin cache")
        portal._v_skindata = None
        portal.setupCurrentSkin()

    ###################################################
    # i18n for NuxMetaDIrectories
    # Use of a Localizer message Catalog.
    ###################################################

    pr(" Adding i18n support for NuxMetaDirectories")
    metadir_catalog_id = 'cpsmetadirectories'

    Localizer = portal['Localizer']
    languages = Localizer.get_supported_languages()

    # Message Catalog
    if metadir_catalog_id in Localizer.objectIds():
        Localizer.manage_delObjects([metadir_catalog_id])
        pr(" Previous default MessageCatalog deleted for NuxMetaDirectories")

    # Adding the new message Catalog
    Localizer.manage_addProduct['Localizer'].manage_addMessageCatalog(
        id=metadir_catalog_id,
        title='NuxMetaDirectories messages',
        languages=languages,
        )

    pr(" NuxMetaDirectories MessageCatalogCreated")

    defaultCatalog = getattr(Localizer, metadir_catalog_id, None)

    # Working now on the po files
    product_path = sys.modules['Products.NuxMetaDirectories'].__path__[0]
    i18n_path = os.path.join(product_path, 'i18n')
    pr(" po files for NuxMetaDirectories are searched in %s" % i18n_path)
    pr(" po files for NuxMetaDirectories %s are expected" % str(languages))

    # loading po files
    for lang in languages:
        po_filename = lang + '.po'
        pr("   importing %s file" % po_filename)
        po_path = os.path.join(i18n_path, po_filename)
        try:
            po_file = open(po_path)
        except (IOError, NameError):
            pr("    %s file not found" % po_path)
        po_path = os.path.join(i18n_path, po_filename)
        try:
            po_file = open(po_path)
        except (IOError, NameError):
            pr("    %s file not found" % po_path)
        else:
            pr("  before  %s file imported" % po_path)
            defaultCatalog.manage_import(lang, po_file)
            pr("    %s file imported" % po_path)

    # Translation Service Tool

    if portalhas('translation_service'):
        translation_service = portal.translation_service
        pr (" Translation Sevice Tool found in here ")

        try:
            if getattr(portal['translation_service'], metadir_catalog_id, None) == None:
                # translation domains
                translation_service.manage_addDomainInfo(metadir_catalog_id,
                                                         'Localizer/'+metadir_catalog_id)
                pr(" cpsmetadirecties domain set to Localizer/cpsmetadirecties")
        except:
            pass
    else:
        raise str('DependanceError'), 'translation_service'

    ######################################################
    # End of i18n for NuxMetaDirectories
    ######################################################

    pr("End of NuxMetaDirectories install")
    return pr('flush')
